@@ -1,18 +1,23 @@
 #' Simple Training/Test Set Splitting
 #'
-#' `initial_split` creates a single binary split of the data into a training
-#'  set and testing set. `initial_time_split` does the same, but takes the
+#' `initial_split()` creates a single binary split of the data into a training
+#'  set and testing set. `initial_time_split()` does the same, but takes the
 #'  _first_ `prop` samples for training, instead of a random selection.
-#'  `group_initial_split` creates splits of the data based
+#'  `group_initial_split()` creates splits of the data based
 #'  on some grouping variable, so that all data in a "group" is assigned to
 #'  the same split.
-#'  `training` and `testing` are used to extract the resulting data.
+#'
+#' @details `training()` and `testing()` are used to extract the resulting data.
+#'
+#' To avoid data leakage when using lagged variables, lag the predictors before
+#' the initial split.
+#'
 #' @template strata_details
 #' @inheritParams vfold_cv
 #' @inheritParams make_strata
 #' @param prop The proportion of data to be retained for modeling/analysis.
 #' @export
-#' @return An `rsplit` object that can be used with the `training` and `testing`
+#' @return An `rsplit` object that can be used with the `training()` and `testing()`
 #'  functions to extract the data in each split.
 #' @examplesIf rlang::is_installed("modeldata")
 #' set.seed(1353)
@@ -24,13 +29,7 @@
 #' drinks_split <- initial_time_split(drinks)
 #' train_data <- training(drinks_split)
 #' test_data <- testing(drinks_split)
-#' c(max(train_data$date), min(test_data$date)) # no lag
-#'
-#' # With 12 period lag
-#' drinks_lag_split <- initial_time_split(drinks, lag = 12)
-#' train_data <- training(drinks_lag_split)
-#' test_data <- testing(drinks_lag_split)
-#' c(max(train_data$date), min(test_data$date)) # 12 period lag
+#' c(max(train_data$date), min(test_data$date))
 #'
 #' set.seed(1353)
 #' car_split <- group_initial_split(mtcars, cyl)
@@ -39,9 +38,17 @@
 #'
 #' @export
 #'
-initial_split <- function(data, prop = 3 / 4,
-                          strata = NULL, breaks = 4, pool = 0.1, ...) {
+initial_split <- function(
+  data,
+  prop = 3 / 4,
+  strata = NULL,
+  breaks = 4,
+  pool = 0.1,
+  ...
+) {
   check_dots_empty()
+  check_prop(prop)
+
   res <-
     mc_cv(
       data = data,
@@ -51,30 +58,53 @@ initial_split <- function(data, prop = 3 / 4,
       pool = pool,
       times = 1
     )
+  attrib <- .get_split_args(res, allow_strata_false = TRUE)
+
   res <- res$splits[[1]]
+
+  attrib$times <- NULL
+  for (i in names(attrib)) {
+    attr(res, i) <- attrib[[i]]
+  }
+
   class(res) <- c("initial_split", class(res))
+
   res
 }
 
 #' @rdname initial_split
-#' @param lag A value to include a lag between the assessment
-#'  and analysis set. This is useful if lagged predictors will be used
-#'  during training and testing.
+#' @param lag `r lifecycle::badge("deprecated")` This is deprecated, please lag
+#' your predictors prior to splitting the dataset.
 #' @export
-initial_time_split <- function(data, prop = 3 / 4, lag = 0, ...) {
+initial_time_split <- function(
+  data,
+  prop = 3 / 4,
+  lag = lifecycle::deprecated(),
+  ...
+) {
   check_dots_empty()
-  if (!is.numeric(prop) | prop >= 1 | prop <= 0) {
-    rlang::abort("`prop` must be a number on (0, 1).")
+  check_prop(prop)
+
+  if (lifecycle::is_present(lag)) {
+    lifecycle::deprecate_soft(
+      when = "1.3.1.9000",
+      what = "initial_time_split(lag)",
+      details = "Please lag your predictors prior to splitting the dataset."
+    )
+  } else {
+    lag <- 0
   }
 
   if (!is.numeric(lag) | !(lag %% 1 == 0)) {
-    rlang::abort("`lag` must be a whole number.")
+    cli_abort("{.arg lag} must be a whole number.")
   }
 
   n_train <- floor(nrow(data) * prop)
 
   if (lag > n_train) {
-    rlang::abort("`lag` must be less than or equal to the number of training observations.")
+    cli_abort(
+      "{.arg lag} must be less than or equal to the number of training observations."
+    )
   }
 
   split <- rsplit(data, 1:n_train, (n_train + 1 - lag):nrow(data))
@@ -83,6 +113,15 @@ initial_time_split <- function(data, prop = 3 / 4, lag = 0, ...) {
   rset <- new_rset(splits, ids)
 
   res <- rset$splits[[1]]
+
+  attrib <- list(
+    prop = prop,
+    lag = lag
+  )
+  for (i in names(attrib)) {
+    attr(res, i) <- attrib[[i]]
+  }
+
   class(res) <- c("initial_time_split", "initial_split", class(res))
   res
 }
@@ -134,27 +173,44 @@ testing.rsplit <- function(x, ...) {
 #' @inheritParams make_groups
 #' @rdname initial_split
 #' @export
-group_initial_split <- function(data, group, prop = 3 / 4, ..., strata = NULL, pool = 0.1) {
+group_initial_split <- function(
+  data,
+  group,
+  prop = 3 / 4,
+  ...,
+  strata = NULL,
+  pool = 0.1
+) {
   check_dots_empty()
+  check_prop(prop)
 
   if (missing(strata)) {
     res <- group_mc_cv(
-        data = data,
-        group = {{ group }},
-        prop = prop,
-        times = 1
-      )
+      data = data,
+      group = {{ group }},
+      prop = prop,
+      times = 1
+    )
   } else {
     res <- group_mc_cv(
-        data = data,
-        group = {{ group }},
-        prop = prop,
-        times = 1,
-        strata = {{ strata }},
-        pool = pool
-      )
+      data = data,
+      group = {{ group }},
+      prop = prop,
+      times = 1,
+      strata = {{ strata }},
+      pool = pool
+    )
   }
+
+  attrib <- .get_split_args(res, allow_strata_false = TRUE)
+
   res <- res$splits[[1]]
+
+  attrib$times <- NULL
+  for (i in names(attrib)) {
+    attr(res, i) <- attrib[[i]]
+  }
   class(res) <- c("group_initial_split", "initial_split", class(res))
+
   res
 }
