@@ -2,18 +2,18 @@
 #'
 #' @param formula An R model formula with one outcome and at least one predictor.
 #' @param data A data frame.
-#' @param model_fn The model to fit. Allowable values are "lm", "glm",
-#'  "survreg", and "coxph". The latter two require that the `survival` package
+#' @param model_fn The model to fit. Allowable values are `"lm"`, `"glm"`,
+#'  `"survreg"`, and `"coxph"`. The latter two require that the survival package
 #'  be installed.
-#' @param type The type of bootstrap confidence interval. Values of "student-t" and
-#' "percentile" are allowed.
+#' @param type The type of bootstrap confidence interval. Values of `"student-t"` and
+#' `"percentile"` are allowed.
 #' @param times A single integer for the number of bootstrap samples. If left
-#' NULL, 1,001 are used for t-intervals and 2,001 for percentile intervals.
+#' `NULL`, 1,001 are used for t-intervals and 2,001 for percentile intervals.
 #' @param alpha Level of significance.
 #' @param filter A logical expression used to remove rows from the final result, or `NULL` to keep all rows.
 #' @param keep_reps Should the individual parameter estimates for each bootstrap
 #' sample be retained?
-#' @param ... Options to pass to the model function (such as `family` for `glm()`).
+#' @param ... Options to pass to the model function (such as `family` for [stats::glm()]).
 #' @return A tibble with columns "term", ".lower", ".estimate", ".upper",
 #' ".alpha", and ".method". If `keep_reps = TRUE`, an additional list column
 #' called ".replicates" is also returned.
@@ -35,9 +35,17 @@
 #' reg_intervals(mpg ~ I(1 / sqrt(disp)), data = mtcars, keep_reps = TRUE)
 #' }
 reg_intervals <-
-  function(formula, data, model_fn = "lm", type = "student-t", times = NULL,
-           alpha = 0.05, filter = term != "(Intercept)", keep_reps = FALSE, ...) {
-
+  function(
+    formula,
+    data,
+    model_fn = "lm",
+    type = "student-t",
+    times = NULL,
+    alpha = 0.05,
+    filter = term != "(Intercept)",
+    keep_reps = FALSE,
+    ...
+  ) {
     rlang::check_installed("broom")
 
     model_fn <- rlang::arg_match(model_fn, c("lm", "glm", "survreg", "coxph"))
@@ -54,12 +62,12 @@ reg_intervals <-
     } else {
       times <- times[1]
       if (!is.numeric(times)) {
-        rlang::abort("'times' should be a single integer.")
+        cli_abort("{.arg times} should be a single integer.")
       }
     }
 
     if (length(alpha) != 1 || !is.numeric(alpha)) {
-      abort("`alpha` must be a single numeric value.")
+      cli_abort("{.arg alpha} must be a single numeric value.")
     }
 
     if (model_fn %in% c("survreg", "coxph")) {
@@ -68,19 +76,26 @@ reg_intervals <-
     } else {
       pkg <- NULL
     }
-    fn_call <- rlang::call2(model_fn,
+    fn_call <- rlang::call2(
+      model_fn,
       formula = formula,
-      data = rlang::expr(data), .ns = pkg, ...
+      data = rlang::expr(data),
+      .ns = pkg,
+      ...
     )
 
-    bt <- rsample::bootstraps(data, times = times, apparent = type %in% c("student-t"))
+    bt <- rsample::bootstraps(
+      data,
+      times = times,
+      apparent = type %in% c("student-t")
+    )
     bt <-
-      dplyr::mutate(bt,
-        models =
-          purrr::map(
-            splits,
-            ~ model_results(rsample::analysis(.x), fn_call, filter)
-          )
+      dplyr::mutate(
+        bt,
+        models = purrr::map(
+          splits,
+          \(.x) model_results(rsample::analysis(.x), fn_call, filter)
+        )
       )
     if (type == "student-t") {
       res <- int_t(bt, models, alpha = alpha)
@@ -90,7 +105,7 @@ reg_intervals <-
 
     if (keep_reps) {
       bt <- bt[bt$id != "Apparent", ]
-      reps <- purrr::map(bt$models, I) %>% list_rbind()
+      reps <- purrr::map(bt$models, I) |> list_rbind()
       reps <- dplyr::group_nest(reps, term, .key = ".replicates")
       res <- dplyr::full_join(res, reps, by = "term")
     }
